import os
from sugarbowl import cachedproperty
from ..find import find
from ..files import find_files
from ..helpers import load, join
from .emitter import ObjectEmitter
from .objname import ObjnameConstraint
from .objtype import ObjtypeConstraint


class find_objects(find):
    """Find objects in files using map_reduce framework.

    Parameters
    ----------
    filters: list
        Find filters.
    basedir: str
        Base directory to find.
    filepathes: list
        List of filepathes or globs where to find.
    params: dict
        Params of map_reduce.

    Returns
    -------
    mixed
        Found files after map_reduce.
    """

    # Public

    default_emitter = ObjectEmitter

    def __init__(self, *, basedir=None, filepathes=None, **params):
        self.__basedir = basedir
        self.__filepathes = filepathes
        super().__init__(**params)

    # Protected

    @cachedproperty
    def _values(self):
        for filepath in self._filepathes:
            # Loads as a module every file in filepathes
            full_filepath = os.path.abspath(join(self.__basedir, filepath))
            module = load(full_filepath)
            for objname in dir(module):
                # Emits every object in module
                objself = getattr(module, objname)
                yield self._emitter(
                    objself, basedir=self.__basedir, filepath=filepath,
                    module=module, objname=objname, objself=objself)

    @cachedproperty
    def _constraints(self):
        constraints = [
            ObjnameConstraint(),
            ObjtypeConstraint()]
        constraints += super()._constraints
        return constraints

    @cachedproperty
    def _filepathes(self):
        filepathes = find_files(
            basedir=self.__basedir,
            filepathes=self.__filepathes,
            filters=self._filters)
        return filepathes
