import re
import unittest
from unittest.mock import Mock
from importlib import import_module
component = import_module('run_find.files.filename')


class FilenameConstraintTest(unittest.TestCase):

    # Actions

    def setUp(self):
        self.constraint = component.FilenameConstraint()
        self.emitter = Mock(filename='filename')

    # Tests

    def test___call___with_filename(self):
        self.constraint.extend('filename', 'f*')
        self.constraint(self.emitter)
        self.assertFalse(self.emitter.skip.called)

    def test___call___with_filename_skip(self):
        self.constraint.extend('filename', 'x*')
        self.constraint(self.emitter)
        self.assertTrue(self.emitter.skip.called)

    def test___call___with_filename_is_regex(self):
        self.constraint.extend('filename', re.compile('f.*'))
        self.constraint(self.emitter)
        self.assertFalse(self.emitter.skip.called)

    def test___call___with_filename_is_regex_skip(self):
        self.constraint.extend('filename', re.compile('x.*'))
        self.constraint(self.emitter)
        self.assertTrue(self.emitter.skip.called)

    def test___call___with_notfilename(self):
        self.constraint.extend('notfilename', 'x*')
        self.constraint(self.emitter)
        self.assertFalse(self.emitter.skip.called)

    def test___call___with_notfilename_skip(self):
        self.constraint.extend('notfilename', 'f*')
        self.constraint(self.emitter)
        self.assertTrue(self.emitter.skip.called)
