import re
import unittest
from functools import partial
from unittest.mock import Mock, patch, call
from importlib import import_module
component = import_module('run_find.objects.find')


class find_objects_Test(unittest.TestCase):

    # Actions

    def setUp(self):
        self.addCleanup(patch.stopall)
        self.filepathes = ['file1', 'file2']
        self.load = Mock(return_value=unittest.mock)
        self.find_files = Mock(return_value=self.filepathes)
        patch.object(component, 'load', self.load).start()
        patch.object(component, 'find_files', self.find_files).start()
        self.pfind = partial(component.find_objects, reducers=[list])

    # Tests

    @unittest.skip
    def test(self):
        objects = self.pfind(basedir='basedir')
        self.assertTrue(objects)
        # Check load call
        self.load.assert_has_calls(
            [call('basedir/file1'),
             call('basedir/file2')])

    def test_with_objname(self):
        objects = self.pfind(filters=[{'objname': 'call'}])
        self.assertEqual(objects, [call, call])

    def test_with_objname_is_regex(self):
        objects = self.pfind(filters=[{'objname': re.compile('^call')}])
        self.assertEqual(objects, [call, call])

    def test_with_objtype(self):
        objects = self.pfind(filters=[{'objtype': type(call)}])
        self.assertEqual(objects, [call, call])

    def test_with_objtype_is_list(self):
        objects = self.pfind(filters=[{'objtype': [type(call)]}])
        self.assertEqual(objects, [call, call])

    def test_with_mapper(self):
        mapper = lambda emitter: emitter.emit(emitter.objtype)
        objects = self.pfind(
            filters=[{'objname': 'call'}],
            mappers=[mapper])
        self.assertEqual(objects, [type(call), type(call)])

    def test_with_reducer_and_fallback(self):
        reducer = lambda values: 1 / 0
        objects = self.pfind(reducers=[reducer], fallback='fallback')
        self.assertEqual(objects, 'fallback')
