import unittest
from unittest.mock import Mock
from importlib import import_module
component = import_module('run_find.objects.objtype')


class ObjtypeConstraintTest(unittest.TestCase):

    # Actions

    def setUp(self):
        self.constraint = component.ObjtypeConstraint()
        self.emitter = Mock(objself=ZeroDivisionError())

    # Tests

    def test___call___with_objtype(self):
        self.constraint.extend('objtype', ArithmeticError)
        self.constraint(self.emitter)
        self.assertFalse(self.emitter.skip.called)

    def test___call___with_objtype_skip(self):
        self.constraint.extend('objtype', AssertionError)
        self.constraint(self.emitter)
        self.assertTrue(self.emitter.skip.called)

    def test___call___with_objtype_is_list(self):
        self.constraint.extend('objtype', [ArithmeticError, BufferError])
        self.constraint(self.emitter)
        self.assertFalse(self.emitter.skip.called)

    def test___call___with_objtype_is_list_skip(self):
        self.constraint.extend('objtype', [AssertionError, AttributeError])
        self.constraint(self.emitter)
        self.assertTrue(self.emitter.skip.called)

    def test___call___with_notobjtype(self):
        self.constraint.extend('notobjtype', AssertionError)
        self.constraint(self.emitter)
        self.assertFalse(self.emitter.skip.called)

    def test___call___with_notobjtype_skip(self):
        self.constraint.extend('notobjtype', ArithmeticError)
        self.constraint(self.emitter)
        self.assertTrue(self.emitter.skip.called)